import { readable } from "svelte/store";
import { is_client, listen } from "svelte/internal";
const defaultWindow = is_client ? window : undefined;
const initialValue = {
    x: 0,
    y: 0,
};
function getCurrentPointerPosition(e) {
    if (!e)
        return initialValue;
    return {
        x: e.pageX,
        y: e.pageY,
    };
}
export function pointerStore(options = {}) {
    const { window = defaultWindow } = options;
    const position = readable(getCurrentPointerPosition(), (set) => {
        function handler(e) {
            set(getCurrentPointerPosition(e));
        }
        if (window) {
            const stopMove = listen(window, "pointermove", handler);
            const stopDown = listen(window, "pointerdown", handler);
            return () => {
                stopMove();
                stopDown();
            };
        }
    });
    return position;
}
