import { defaultWindow, tryOnDestroy } from "../../shared";
/**
 * Wrapper for `requestAnimationFrame` with controls.
 *
 * @param cb
 * @param interval
 * @param options
 */
export function rafFnStore(fn, { window = defaultWindow } = {}) {
    let timerId = undefined;
    function clean() {
        if (timerId) {
            window?.cancelAnimationFrame(timerId);
            timerId = undefined;
        }
    }
    function pause() {
        clean();
    }
    function loop() {
        if (timerId) {
            fn();
            timerId = window?.requestAnimationFrame(loop);
        }
    }
    function resume() {
        clean();
        timerId = window?.requestAnimationFrame(loop);
    }
    tryOnDestroy(pause);
    resume();
    return {
        resume,
        pause,
    };
}
